@@ -20,6 +20,14 @@ extern void F77_NAME(gspcore)(void *, void *, void *, void *, void *, void *, vo
 extern void F77_NAME(gspcoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(gtecore)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(gtecoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmrcore)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmrcoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmtcore)(void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmtcoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmmrcore)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmmrcoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmmtcore)(void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(kmmtcoreinh)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 static const R_FortranMethodDef FortranEntries[] = {
 
   {"astk",          (DL_FUNC) &F77_NAME(astk),          15},
@@ -33,6 +41,14 @@ static const R_FortranMethodDef FortranEntries[] = {
   {"gspcoreinh",  (DL_FUNC) &F77_NAME(gspcoreinh),  16},
   {"gtecore",  (DL_FUNC) &F77_NAME(gtecore),  9},
   {"gtecoreinh",  (DL_FUNC) &F77_NAME(gtecoreinh),  16},
+  {"kmrcore",  (DL_FUNC) &F77_NAME(kmrcore),  9},
+  {"kmrcoreinh",  (DL_FUNC) &F77_NAME(kmrcoreinh),  16},
+  {"kmtcore",  (DL_FUNC) &F77_NAME(kmtcore),  8},
+  {"kmtcoreinh",  (DL_FUNC) &F77_NAME(kmtcoreinh),  15},
+  {"kmmrcore",  (DL_FUNC) &F77_NAME(kmrcore),  9},
+  {"kmmrcoreinh",  (DL_FUNC) &F77_NAME(kmrcoreinh),  16},
+  {"kmmtcore",  (DL_FUNC) &F77_NAME(kmtcore),  8},
+  {"kmmtcoreinh",  (DL_FUNC) &F77_NAME(kmtcoreinh),  15},
   {NULL, NULL, 0}
 };
 
